@@ -14,7 +14,7 @@ on other items.
 This module uses the mxDateTime package for handling date/time types.
 """
 
-__version__ = """$Revision: 1.39 $"""[11:-2]
+__version__ = """$Revision: 1.40 $"""[11:-2]
 
 import _mysql
 from _mysql import *
@@ -227,7 +227,7 @@ class BaseCursor:
                 raise
         qv = query[p:]
         for a in args[1:]: q.append(qv % escape(a, qc))
-        return self._thequery(join(q, ',\n'))
+        return self._query(join(q, ',\n'))
 
     def __do_query(self, q):
         from string import split, atoi
